@@ -683,7 +683,12 @@ class Exploit < Msf::Module
   # The target index that has been selected.
   #
   def target_index
-    target_idx = Integer(datastore['TARGET']) rescue datastore['TARGET']
+    target_idx =
+      begin
+        Integer(datastore['TARGET'])
+      rescue ArgumentError, TypeError
+        datastore['TARGET']
+      end
 
     default_idx = default_target || 0
     # Use the default target if one was not supplied.
@@ -761,12 +766,19 @@ class Exploit < Msf::Module
 
     c_platform, c_arch = normalize_platform_arch
 
-    framework.payloads.each_module(
-      'Arch' => c_arch, 'Platform' => c_platform) { |name, mod|
-      payloads << [ name, mod ] if is_payload_compatible?(name)
-    }
+    results = Msf::Modules::Metadata::Cache.instance.find(
+      'type'     => [['payload'], []],
+      'platform' => [[*c_platform.names, 'All'], []], # "All" for generic
+      'arch'     => [c_arch, []]
+    )
 
-    return payloads;
+    results.each do |res|
+      if is_payload_compatible?(res.ref_name)
+        payloads << [res.ref_name, framework.payloads[res.ref_name]]
+      end
+    end
+
+    payloads
   end
 
   #
