@@ -82,6 +82,9 @@ module Exploit::Remote::HttpClient
     register_autofilter_services(%W{ http https })
   end
 
+  def deregister_http_client_options
+    deregister_options('RHOST', 'RPORT', 'VHOST', 'SSL', 'Proxies')
+  end
 
   #
   # For HTTP Client exploits, we often want to verify that the server info matches some regex before
