@@ -224,7 +224,7 @@ module Exploit::Powershell
   def cmd_psh_payload(pay, payload_arch, opts = {})
     %i[persist prepend_sleep exec_in_place encode_final_payload encode_inner_payload
     remove_comspec noninteractive wrap_double_quotes no_equals method].map do |opt|
-      opts[opt] = opts[opt].nil? ? datastore["Powershell::#{opt}"] : opts[opt]
+      opts[opt] = datastore["Powershell::#{opt}"] if opts[opt].nil?
     end
 
     unless opts.key? :shorten
