@@ -6,6 +6,7 @@ require 'rex/post/meterpreter'
 require 'rex/socket/x509_certificate'
 require 'msf/core/payload/windows/verify_ssl'
 require 'rex/user_agent'
+require 'uri'
 
 module Msf
 module Handler
@@ -118,9 +119,9 @@ module ReverseHttp
 
     # Extract whatever the client sent us in the Host header
     if req && req.headers && req.headers['Host']
-        callback_host, callback_port = req.headers['Host'].split(":")
-        callback_port = callback_port.to_i
-        callback_port ||= (ssl? ? 443 : 80)
+      cburi = URI("#{scheme}://#{req.headers['Host']}")
+      callback_host = cburi.host
+      callback_port = cburi.port
     end
 
     # Override the host and port as appropriate
@@ -239,8 +240,7 @@ module ReverseHttp
     lookup_proxy_settings
 
     if datastore['IgnoreUnknownPayloads']
-      payload_count = framework.db.payloads({workspace: framework.db.workspace}).length
-      print_status("Handler is ignoring unknown payloads, there are #{payload_count} UUIDs whitelisted")
+      print_status("Handler is ignoring unknown payloads")
     end
   end
 
@@ -333,9 +333,8 @@ protected
     if datastore['IgnoreUnknownPayloads'] && info[:mode].to_s =~ /^init_/
       payload_info = {
           uuid: uuid.puid_hex,
-          workspace: framework.db.workspace
       }
-      payload = framework.db.payloads(payload_info).first
+      payload = framework.db.get_payload(payload_info)
       allowed_urls = payload ? payload.urls : []
       unless allowed_urls.include?(req.relative_resource)
         print_status("Ignoring unknown UUID URL: #{request_summary}")
